# Network Structural Profile

Navigating the profile

- the profile includes the following sections by default:

- global properties
- overview of node centrality and partition distributions
- detail views of node centrality distributions
- node centrality correlations
- detail views of partitions

- click [+] for descriptions of measures
- click on distribution thumbnail for detail view
- hover over variable name of statistical figures for explanation
- click on distribution plot for larger view

{properties[Name]}
{properties[Nodes]}
{properties[Edges]}
{properties[Density]:g}
{properties[Directed]}
{properties[Weighted]}
{properties[Self Loops]:g}
{properties[Diameter Range]}
{properties[Effective Diameter]}
{properties[Connected Components]}
{results[Node Centrality][Overview]}
{results[Partition][Overview]}
{results[Node Centrality][Measures]}
{results[Node Centrality][Correlations][HeatMaps]} {results[Node Centrality][Correlations][ScatterPlots]}
{results[Partition][Measures]}